aboutsummaryrefslogtreecommitdiffstats
path: root/plugins/wimax/msg_dcd.c
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/wimax/msg_dcd.c')
-rw-r--r--plugins/wimax/msg_dcd.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins/wimax/msg_dcd.c b/plugins/wimax/msg_dcd.c
index be745359b4..95b3a06877 100644
--- a/plugins/wimax/msg_dcd.c
+++ b/plugins/wimax/msg_dcd.c
@@ -38,7 +38,7 @@
#include "moduleinfo.h"
-#include <gmodule.h>
+#include <glib.h>
#include <epan/packet.h>
#include <epan/prefs.h>
#include "wimax_tlv.h"
@@ -886,8 +886,8 @@ void dissect_mac_mgmt_msg_dcd_decoder(tvbuff_t *tvb, packet_info *pinfo, proto_t
if(tree)
{ /* we are being asked for details */
- /* Get the tvb length */
- tvb_len = tvb_length(tvb);
+ /* Get the tvb reported length */
+ tvb_len = tvb_reported_length(tvb);
/* display MAC payload type DCD */
dcd_item = proto_tree_add_protocol_format(tree, proto_mac_mgmt_msg_dcd_decoder, tvb, offset, tvb_len, "Downlink Channel Descriptor (DCD) (%u bytes)", tvb_len);
/* add MAC DCD subtree */